@@ -4,16 +4,14 @@ Main interface for managedblockchain service.
 Usage::
 
     ```python
-    import boto3
+    from boto3.session import Session
     from mypy_boto3_managedblockchain import (
         Client,
         ManagedBlockchainClient,
     )
 
-    session = boto3.Session()
-
-    client: ManagedBlockchainClient = boto3.client("managedblockchain")
-    session_client: ManagedBlockchainClient = session.client("managedblockchain")
+    session = Session()
+    client: ManagedBlockchainClient = session.client("managedblockchain")
     ```
 """
 from .client import ManagedBlockchainClient
