@@ -1,7 +1,7 @@
 """
 Type annotations for managedblockchain service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_managedblockchain/literals.html)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_managedblockchain/literals/)
 
 Usage::
 
@@ -30,7 +30,10 @@ __all__ = (
     "StateDBTypeType",
     "ThresholdComparatorType",
     "VoteValueType",
+    "ManagedBlockchainServiceName",
     "ServiceName",
+    "ResourceServiceName",
+    "RegionName",
 )
 
 
@@ -62,6 +65,7 @@ ProposalStatusType = Literal["ACTION_FAILED", "APPROVED", "EXPIRED", "IN_PROGRES
 StateDBTypeType = Literal["CouchDB", "LevelDB"]
 ThresholdComparatorType = Literal["GREATER_THAN", "GREATER_THAN_OR_EQUAL_TO"]
 VoteValueType = Literal["NO", "YES"]
+ManagedBlockchainServiceName = Literal["managedblockchain"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -93,11 +97,13 @@ ServiceName = Literal[
     "backup",
     "backup-gateway",
     "batch",
+    "billingconductor",
     "braket",
     "budgets",
     "ce",
     "chime",
     "chime-sdk-identity",
+    "chime-sdk-media-pipelines",
     "chime-sdk-meetings",
     "chime-sdk-messaging",
     "cloud9",
@@ -179,6 +185,7 @@ ServiceName = Literal[
     "frauddetector",
     "fsx",
     "gamelift",
+    "gamesparks",
     "glacier",
     "globalaccelerator",
     "glue",
@@ -212,9 +219,11 @@ ServiceName = Literal[
     "iottwinmaker",
     "iotwireless",
     "ivs",
+    "ivschat",
     "kafka",
     "kafkaconnect",
     "kendra",
+    "keyspaces",
     "kinesis",
     "kinesis-video-archived-media",
     "kinesis-video-media",
@@ -279,6 +288,7 @@ ServiceName = Literal[
     "pinpoint",
     "pinpoint-email",
     "pinpoint-sms-voice",
+    "pinpoint-sms-voice-v2",
     "polly",
     "pricing",
     "proton",
@@ -363,3 +373,18 @@ ServiceName = Literal[
     "workspaces-web",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
+RegionName = Literal[
+    "ap-northeast-1", "ap-northeast-2", "ap-southeast-1", "eu-west-1", "eu-west-2", "us-east-1"
+]
